@@ -3,10 +3,11 @@
 import inspect
 import re
 from argparse import Namespace
-from typing import Any, Callable, List, Optional, Set, Type, Union
+from typing import Any, Callable, List, Optional, Set, Tuple, Type, Union
 
-from .actions import _ActionConfigLoad, _ActionHelpClassPath
+from .actions import _ActionConfigLoad, _ActionHelpClass, _ActionHelpClassPath
 from .typehints import ActionTypeHint, is_optional
+from .typing import is_final_class
 from .util import _get_key_value, _issubclass
 from .optionals import (
     dataclasses_support,
@@ -262,13 +263,14 @@ class SignatureArguments:
         group,
         nested_key: Optional[str],
         param,
-        obj: Type,
+        obj: Any,
         doc_params: dict,
         added_args: List[str],
         skip: Set[str],
         fail_untyped: bool = True,
         as_positional: bool = False,
         sub_configs: bool = False,
+        instantiate: bool = True,
         linked_targets: Optional[Set[str]] = None,
         add_args: bool = True,
         add_kwargs: bool = True,
@@ -281,7 +283,7 @@ class SignatureArguments:
         if default == inspect_empty:
             default = param.default
         is_required = default == inspect_empty
-        skip_message = 'Skipping parameter "'+name+'" from "'+obj.__name__+'" because of: '
+        skip_message = 'Skipping parameter "'+name+'" from "'+getattr(obj, '__name__', str(obj))+'" because of: '
         if not fail_untyped and annotation == inspect_empty:
             annotation = Any
             default = None if is_required else default
@@ -314,15 +316,15 @@ class SignatureArguments:
                 annotation = Optional[annotation]
         elif not as_positional:
             kwargs['required'] = True
-        is_subclass_typehint = False
+        is_class_typehint = False
         if annotation in {str, int, float, bool} or \
            _issubclass(annotation, (str, int, float)) or \
            is_pure_dataclass(annotation):
             kwargs['type'] = annotation
         elif annotation != inspect_empty:
             try:
-                is_subclass_typehint = ActionTypeHint.is_subclass_typehint(annotation)
-                enable_path = is_subclass_typehint and sub_configs
+                is_class_typehint = ActionTypeHint.is_class_typehint(annotation)
+                enable_path = is_class_typehint and sub_configs
                 kwargs['action'] = ActionTypeHint(typehint=annotation, enable_path=enable_path)
             except ValueError as ex:
                 self.logger.debug(skip_message+str(ex))  # type: ignore
@@ -332,16 +334,21 @@ class SignatureArguments:
                 self.logger.debug(skip_message+'Argument already added.')  # type: ignore
             else:
                 opt_str = dest if is_required and as_positional else '--'+dest
-                if is_subclass_typehint:
-                    group.add_argument('--'+dest+'.help', action=_ActionHelpClassPath(baseclass=annotation))
-                    init = name + '.init_args.'
-                    subclass_skip = {s[len(init):] for s in skip if s.startswith(init)}
+                if is_class_typehint:
+                    help_action = _ActionHelpClass
+                    prefix = name + '.'
+                    if ActionTypeHint.is_subclass_typehint(annotation):
+                        help_action = _ActionHelpClassPath
+                        prefix = name + '.init_args.'
+                    group.add_argument('--'+dest+'.help', action=help_action(baseclass=annotation))
+                    subclass_skip = {s[len(prefix):] for s in skip if s.startswith(prefix)}
                 action = group.add_argument(opt_str, **kwargs)
                 action.sub_add_kwargs = {
                     'fail_untyped': fail_untyped,
                     'sub_configs': sub_configs,
+                    'instantiate': instantiate,
                 }
-                if is_subclass_typehint and len(subclass_skip) > 0:
+                if is_class_typehint and len(subclass_skip) > 0:
                     action.sub_add_kwargs['skip'] = subclass_skip
                 added_args.append(dest)
         elif is_required and fail_untyped:
@@ -412,10 +419,11 @@ class SignatureArguments:
 
     def add_subclass_arguments(
         self,
-        baseclass: Type,
+        baseclass: Union[Type, Tuple[Type, ...]],
         nested_key: str,
         as_group: bool = True,
         skip: Optional[Set[str]] = None,
+        instantiate: bool = True,
         required: bool = False,
         metavar: str = '{"class_path":...[,"init_args":...]}',
         help: str = 'Dictionary with "class_path" and "init_args" for any subclass of %(baseclass_name)s.',
@@ -431,7 +439,7 @@ class SignatureArguments:
         argument is added that will print the details for a given class path.
 
         Args:
-            baseclass: Base class to use to check subclasses.
+            baseclass: Base class or classes to use to check subclasses.
             nested_key: Key for nested namespace.
             as_group: Whether arguments should be added to a new argument group.
             skip: Names of parameters that should be skipped.
@@ -442,10 +450,14 @@ class SignatureArguments:
         Raises:
             ValueError: When not given a class.
         """
-        if not inspect.isclass(baseclass):
-            raise ValueError('Expected "baseclass" argument to be a class object.')
+        if is_final_class(baseclass):
+            raise ValueError("Not allowed for classes that are final.")
+        if type(baseclass) is not tuple:
+            baseclass = (baseclass,)  # type: ignore
+        if not all(inspect.isclass(c) for c in baseclass):
+            raise ValueError('Expected "baseclass" argument to be a class or a tuple of classes.')
 
-        doc_group = self._gather_docstrings([baseclass], get_class_init_and_base_docstrings)[0]
+        doc_group = self._gather_docstrings(baseclass, get_class_init_and_base_docstrings)[0]
         group = self._create_group_if_requested(
             baseclass,
             nested_key,
@@ -461,21 +473,22 @@ class SignatureArguments:
             skip = set()
         else:
             skip = set(nested_key+'.init_args.'+s for s in skip)
-        param = Namespace(name=nested_key, _kind=None, annotation=baseclass)
+        param = Namespace(name=nested_key, _kind=None, annotation=Union[baseclass])
         kwargs.update({
             'metavar': metavar,
-            'help': (help % {'baseclass_name': baseclass.__name__}),
+            'help': (help % {'baseclass_name': str(baseclass)}),
         })
         self._add_signature_parameter(
             group,
             None,
             param,
-            baseclass,
+            Union[baseclass],
             {},
             added_args,
             skip,
             default={},
             sub_configs=True,
+            instantiate=instantiate,
             **kwargs
         )
 
