@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 
 import calendar
-from collections import defaultdict
 import json
+import platform
 import yaml
 from enum import Enum
 from io import StringIO
@@ -247,12 +247,20 @@ class SignaturesTests(unittest.TestCase):
 
 
     def test_add_subclass_arguments(self):
-        parser = ArgumentParser(error_handler=None)
+        parser = ArgumentParser(error_handler=None, parse_as_dict=True)
         parser.add_subclass_arguments(calendar.Calendar, 'cal')
 
         cal = {'class_path': 'calendar.Calendar', 'init_args': {'firstweekday': 1}}
         cfg = parser.parse_args(['--cal='+json.dumps(cal)])
-        self.assertEqual(namespace_to_dict(cfg.cal), cal)
+        self.assertEqual(cfg['cal'], cal)
+
+        cal['init_args']['firstweekday'] = 2
+        cfg = parser.parse_args(['--cal.class_path=calendar.Calendar', '--cal.init_args.firstweekday=2'])
+        self.assertEqual(cfg['cal'], cal)
+
+        cal['init_args']['firstweekday'] = 3
+        cfg = parser.parse_args(['--cal.class_path', 'calendar.Calendar', '--cal.init_args.firstweekday', '3'])
+        self.assertEqual(cfg['cal'], cal)
 
         self.assertRaises(ParserError, lambda: parser.parse_args(['--cal={"class_path":"not.exist.Class"}']))
         self.assertRaises(ParserError, lambda: parser.parse_args(['--cal={"class_path":"calendar.January"}']))
@@ -262,9 +270,30 @@ class SignaturesTests(unittest.TestCase):
         out = StringIO()
         with redirect_stdout(out), self.assertRaises(SystemExit):
             parser.parse_args(['--cal.help=calendar.Calendar'])
-
         self.assertIn('--cal.init_args.firstweekday', out.getvalue())
 
+        if platform.python_implementation() == 'CPython':
+            cal['init_args']['firstweekday'] = 4
+            lazy_calendar = lazy_instance(calendar.Calendar, firstweekday=4)
+            parser.set_defaults({'cal': lazy_calendar})
+            cfg = parser.parse_string(parser.dump(parser.parse_args([])))
+            self.assertEqual(cfg['cal'], cal)
+            self.assertEqual(lazy_calendar.getfirstweekday(), 4)
+
+            parser.add_argument('--config', action=ActionConfigFile)
+            out = StringIO()
+            with redirect_stdout(out), self.assertRaises(SystemExit):
+                parser.parse_args(['--print_config'])
+            self.assertIn('class_path: calendar.Calendar', out.getvalue())
+
+        parser.set_defaults({'cal': calendar.Calendar(firstweekday=4)})
+        cfg = parser.parse_args([])
+        self.assertIsInstance(cfg['cal'], calendar.Calendar)
+        cfg = parser.instantiate_subclasses(cfg)
+        self.assertIsInstance(cfg['cal'], calendar.Calendar)
+        dump = parser.dump(cfg)
+        self.assertIn('cal: <calendar.Calendar object at ', dump)
+
 
     def test_add_subclass_arguments_tuple(self):
 
